@@ -475,7 +475,8 @@ def upload_file(
     path, 
     metadata={}, 
     directory='/',
-    overwrite=True):
+    overwrite=True,
+    dataset_id=None):
     """
     Upload file to Cognite
     
@@ -484,6 +485,7 @@ def upload_file(
         - path: path of local file to upload
         - metadata: dictionary with file metadata
         - overwrite: what to do when the external_id exists already
+        - dataset_id: (int) dataset id
     """
     client = global_client["files"]
     
@@ -496,7 +498,8 @@ def upload_file(
         external_id, 
         metadata=metadata, 
         directory=directory, 
-        overwrite=overwrite
+        overwrite=overwrite,
+        data_set_id=dataset_id
     )
     logging.info(f"Uploaded file: {file_info=}")
     return file_info
@@ -507,7 +510,8 @@ def upload_folder(
     path, 
     metadata={}, 
     overwrite=False, 
-    target_folder='/'
+    target_folder='/',
+    dataset_id=None
 ):
     """
     Upload folder content to Cognite. It compresses the folder and uploads it.
@@ -518,6 +522,7 @@ def upload_folder(
         - metadata: dictionary with file metadata
         - target_folder: path where compressed file should be stored
         - overwrite: if overwrite==False and `external_id` exists => exception
+        - dataset_id: (int) dataset id
     """
     base_name = path / 'archive'
     archive_name = make_archive(base_name, 'gztar', path)
@@ -526,7 +531,8 @@ def upload_folder(
         archive_name, 
         metadata=metadata,
         overwrite=overwrite,
-        directory=target_folder
+        directory=target_folder,
+        data_set_id=dataset_id
     )
     os.remove(archive_name)
     logging.info(f"Folder content uploaded: {file_info=}")
@@ -565,7 +571,8 @@ def query_file_versions(
     directory_prefix, 
     external_id_prefix, 
     metadata={}, 
-    uploaded=True):
+    uploaded=True,
+    dataset_id=None):
     """
     Find all file versions that match a query. 
 
@@ -573,6 +580,8 @@ def query_file_versions(
         -directory_prefix
         -external_id_prefix
         -metadata: query to the metadata (dictionary)
+        -uploaded: (bool)
+        -dataset_id: (int) dataset id
     Output:
         - list of versions (dataframe)
     """
@@ -582,7 +591,8 @@ def query_file_versions(
         directory_prefix=directory_prefix, 
         external_id_prefix=external_id_prefix,
         metadata=metadata,
-        uploaded=uploaded
+        uploaded=uploaded,
+        data_set_ids=dataset_id
     ).to_pandas()
 
     return file_list
@@ -600,7 +610,7 @@ def delete_file(id):
     logging.debug(f"Deleted file with {id=}")
 
 
-def copy_file(source_ext_id, target_ext_id, overwrite=False):
+def copy_file(source_ext_id, target_ext_id, overwrite=False, dataset_id=None):
     """
     Copy content and metadata of a file in CDF Files
 
@@ -608,6 +618,7 @@ def copy_file(source_ext_id, target_ext_id, overwrite=False):
         - source_ext_id: (str) external id for source file
         - target_ext_id: (str) external id for target file
         - overwrite: (bool) should target file be overwritten if it exists
+        - dataset_id: (int) dataset id for the target file
     """
     client = global_client["files"]
     f = client.files.retrieve(external_id=source_ext_id)
@@ -619,30 +630,44 @@ def copy_file(source_ext_id, target_ext_id, overwrite=False):
         external_id=target_ext_id,
         metadata=f.metadata, 
         directory=f.directory, 
-        overwrite=overwrite
+        overwrite=overwrite,
+        data_set_id=dataset_id
     )
     m = f"Copied source {source_ext_id} to {target_ext_id}, {f.dump()}"
     logging.info(m)
 
 
-def file_exists(external_id, directory):
+def file_exists(external_id, directory, dataset_id=None):
     """
     Check if a file exists in a folder (regardless of uploaded status)
 
     Input:
         - external_id: (str)
         - directory: (str)
+        - dataset_id: (int)
     Output
         - exists: (bool)
     """
     file_list = query_file_versions(
         directory_prefix=directory, 
         external_id_prefix=external_id,
-        uploaded=None
+        uploaded=None, data_set_id=dataset_id
     )
     if file_list.empty:
         logging.info(f"File with '{external_id=}' not found")
-        exists =  False
+        exists = False
     else:
         exists = True
-    return exists
\ No newline at end of file
+    return exists
+
+
+def get_dataset_id(external_id):
+    """
+    Input:
+        -external_id: (str)
+    Output:
+        -id: (int)
+    """
+    client = global_client["files"]
+    dataset = client.data_sets.retrieve(external_id=external_id)
+    return dataset.id
\ No newline at end of file
