@@ -4,10 +4,15 @@ from pathlib import Path
 
 import akerbp.mlops.cdf.helpers as cdf
 from akerbp.mlops.core import config, logger
+from akerbp.mlops.core.helpers import confirm_prompt
+
 env = config.envs.env
 logging=logger.get_logger(name='mlops_model_manager')
 
 
+mlops_dataset_id = None
+
+
 def setup(cdf_api_keys=None):
     """
     Set up the model manager. Currently this involves only setting up the CDF
@@ -19,6 +24,8 @@ def setup(cdf_api_keys=None):
     if cdf_api_keys:
         cdf.api_keys = cdf_api_keys
     cdf.set_up_cdf_client()
+    global mlops_dataset_id
+    mlops_dataset_id = cdf.get_dataset_id('mlops')
 
 
 def upload_new_model_version(model_name, env, folder, metadata={}):
@@ -40,7 +47,8 @@ def upload_new_model_version(model_name, env, folder, metadata={}):
     file_list = cdf.query_file_versions(
         external_id_prefix= f"{model_name}/{env}/", 
         directory_prefix='/mlops', 
-        uploaded=None # count any file
+        uploaded=None, # count any file
+        dataset_id=mlops_dataset_id
     )
     if not file_list.empty:
         latest_v = file_list.metadata.apply(lambda d:int(d["version"])).max()
@@ -63,7 +71,8 @@ def upload_new_model_version(model_name, env, folder, metadata={}):
         external_id, 
         folder, 
         metadata,
-        target_folder='/mlops'
+        target_folder='/mlops',
+        dataset_id=mlops_dataset_id
     )
     logging.info(f"Uploaded model with {external_id=} from {folder}")
     return folder_info
@@ -84,7 +93,8 @@ def find_model_version(model_name, env, metadata):
     file_list = cdf.query_file_versions(
         directory_prefix='/mlops', 
         external_id_prefix=f"{model_name}/{env}",
-        metadata=metadata
+        metadata=metadata,
+        dataset_id=mlops_dataset_id
     )
 
     if (n_models := file_list.shape[0]) == 0:
@@ -164,7 +174,8 @@ def get_model_version_overview(model_name=None, env=None, metadata={}):
         directory_prefix='/mlops', 
         external_id_prefix=None,
         uploaded=None,
-        metadata=metadata
+        metadata=metadata,
+        dataset_id=mlops_dataset_id
     )
 
     # query the external id
@@ -177,6 +188,36 @@ def get_model_version_overview(model_name=None, env=None, metadata={}):
     return file_list
 
 
+def validate_model_id(external_id, verbose=True):
+    """
+    Validate that model id follows MLOps standard: model/env/id
+
+    Input: (string) model id to validate
+    Output: (bool) True if name is valid, False otherwise
+    """
+    supported_environments = ["dev", "test", "prod"]
+    try:
+        model, environment, version = external_id.split("/")
+    except ValueError:
+        if verbose:
+            m = f"Expected model id format: 'model/env/id'"
+            logging.error(m)
+        return False
+    if environment not in supported_environments:
+        if verbose:
+            m = f"Supported environments: {supported_environments}"
+            logging.error(m)
+        return False
+    try:
+        int(version)
+    except ValueError:
+        if verbose:
+            m = f"Version should be integer, got '{version}' instead"
+            logging.error(m)
+        return False
+    return True
+
+
 def delete_model_version(external_id, confirm=True):
     """
     Delete a model artifact version
@@ -188,31 +229,38 @@ def delete_model_version(external_id, confirm=True):
             the function `get_model_version_overview`
         - confirm: (bool) whether the user will be asked to confirm deletion
     """
-    try:
-        model, environment, version = external_id.split("/")
-    except ValueError:
-        logging.error(f"Expected external id format: 'name/env/version'")
+    if not validate_model_id(external_id):
+        raise ValueError()
+    model, environment, version = external_id.split("/")
+    if not cdf.file_exists(external_id, '/mlops'):
         return
 
     confirmed = False
-
-    file_list = cdf.query_file_versions(
-        directory_prefix='/mlops', 
-        external_id_prefix=external_id,
-        uploaded=None
-    )
-    if file_list.empty:
-        logging.error(f"File with '{external_id=}' not found")
-        return
-
     if confirm:
-        def confirm_prompt(question):
-            reply = None
-            while reply not in ("y", "n"):
-                reply = input(f"{question} (y/n): ").lower()
-            return (reply == "y")
         question = f"Delete {model=}, {environment=}, {version=}?"
         confirmed = confirm_prompt(question)
 
     if not confirm or confirmed:
-        cdf.delete_file(dict(external_id=external_id))
\ No newline at end of file
+        cdf.delete_file(dict(external_id=external_id))
+
+
+def promote_model(model_name, version, confirm=True):
+    """
+    Promote a model version from test to prod
+
+    Input:
+        - model_name: (str)
+        - version: (int or str) model's version in test
+    """
+    external_id = f"{model_name}/test/{version}"
+    if not cdf.file_exists(external_id, '/mlops', dataset_id=mlops_dataset_id):
+        return
+
+    confirmed = False
+    if confirm:
+        question = f"Promote {model_name=}, environment=test, {version=}?"
+        confirmed = confirm_prompt(question)
+
+    target_ext_id = f"{model_name}/prod/{version}"
+    if not confirm or confirmed:
+        cdf.copy_file(external_id, target_ext_id)
\ No newline at end of file
